---
categories: [it, program]
tags: [VSCode, FAQ]
lang: ru
---

# Installing VSCode

## Section

Example text.

![Alt text](img/image1.png)

Example text.

```markdown
Example text.

![Alt text](img/image1.png)

Example text.

## About
```

## About

Another text.

![Alt text 2](img/image2.png)

_Рисунок 22 — Alt ds sdsd text_

Another text.

![Alt text](img/image3.png)
